summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/options.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/options.h')
-rw-r--r--kpilot/lib/options.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kpilot/lib/options.h b/kpilot/lib/options.h
index 6e036e82..9fe0f8be 100644
--- a/kpilot/lib/options.h
+++ b/kpilot/lib/options.h
@@ -36,9 +36,9 @@
#include "config.h"
-#include <qglobal.h>
-#include <qnamespace.h>
-#include <qstring.h>
+#include <tqglobal.h>
+#include <tqnamespace.h>
+#include <tqstring.h>
#if (QT_VERSION < 0x030300)
#error "This is KPilot for KDE3.5 and won't compile with Qt < 3.3.0"
@@ -61,9 +61,9 @@
#include <iostream>
using namespace std;
-inline std::ostream& operator <<(std::ostream &o, const QString &s)
+inline std::ostream& operator <<(std::ostream &o, const TQString &s)
{ if (s.isEmpty()) return o<<"<empty>"; else return o<<s.latin1(); }
-inline std::ostream& operator <<(std::ostream &o, const QCString &s)
+inline std::ostream& operator <<(std::ostream &o, const TQCString &s)
{ if (s.isEmpty()) return o<<"<empty>"; else return o << *s; }
@@ -144,19 +144,19 @@ inline std::ostream& operator <<(std::ostream &o, const KPilotDepthCount &d)
// Function to expand newlines in rich text to <br>\n
-QString rtExpand(const QString &s, Qt::TextFormat richText);
+TQString rtExpand(const TQString &s, Qt::TextFormat richText);
/**
* Convert a struct tm from the pilot-link package to a QDateTime
*/
-KDE_EXPORT QDateTime readTm(const struct tm &t);
+KDE_EXPORT TQDateTime readTm(const struct tm &t);
/**
* Convert a QDateTime to a struct tm for use with the pilot-link package
*/
-KDE_EXPORT struct tm writeTm(const QDateTime &dt);
-KDE_EXPORT struct tm writeTm(const QDate &dt);
+KDE_EXPORT struct tm writeTm(const TQDateTime &dt);
+KDE_EXPORT struct tm writeTm(const TQDate &dt);
// Some layout macros
@@ -180,7 +180,7 @@ KDE_EXPORT struct tm writeTm(const QDate &dt);
// variant is to handle plurals and is wrong, but unavoidable.
//
//
-#define TODO_I18N(a) QString::fromLatin1(a)
+#define TODO_I18N(a) TQString::fromLatin1(a)
#define TODO_I18N_P(a,b,c) ((c>1) ? a : b)
// Handle some cases for QT_NO_CAST_ASCII and NO_ASCII_CAST.
@@ -194,6 +194,6 @@ KDE_EXPORT struct tm writeTm(const QDate &dt);
// with constant strings.
//
//
-#define CSL1(a) QString::fromLatin1(a "")
+#define CSL1(a) TQString::fromLatin1(a "")
#endif
@@ -144,19 +144,19 @@ inline std::ostream& operator <<(std::ostream &o, const KPilotDepthCount &d)
/**
- * Convert a QDateTime to a struct tm for use with the pilot-link package
+ * Convert a TQDateTime to a struct tm for use with the pilot-link package
*/